@@ -11,16 +11,28 @@ impl Signer for SoftwareVault {
         let entry = self.get_entry(secret_key)?;
         let key = entry.key().as_ref();
         match entry.key_attributes().stype() {
-            SecretType::Curve25519 if key.len() == CURVE25519_SECRET_LENGTH => {
-                let mut rng = thread_rng();
-                let mut nonce = [0u8; 64];
-                rng.fill_bytes(&mut nonce);
-                let sig =
-                    x25519_dalek::StaticSecret::from(*array_ref!(key, 0, CURVE25519_SECRET_LENGTH))
-                        .sign(data.as_ref(), &nonce);
-                Ok(sig)
+            SecretType::Curve25519 => {
+                if key.len() == CURVE25519_SECRET_LENGTH {
+                    let mut rng = thread_rng();
+                    let mut nonce = [0u8; 64];
+                    rng.fill_bytes(&mut nonce);
+                    let sig = x25519_dalek::StaticSecret::from(*array_ref!(
+                        key,
+                        0,
+                        CURVE25519_SECRET_LENGTH
+                    ))
+                    .sign(data.as_ref(), &nonce);
+                    Ok(sig)
+                } else {
+                    Err(VaultError::InvalidKeyType.into())
+                }
+            }
+            SecretType::Bls => {
+                unimplemented!()
+            }
+            SecretType::Buffer | SecretType::Aes | SecretType::P256 => {
+                Err(VaultError::InvalidKeyType.into())
             }
-            _ => Err(VaultError::InvalidKeyType.into()),
         }
     }
 }
